@@ -149,7 +149,8 @@ SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_ann
   int numAllocated = 0;
   
   // allocate return value
-  numAllocated += createList(nGene, &ans);
+  PROTECT(ans = allocVector(VECSXP, nGene));
+  numAllocated++;
   numAllocated += setListNames(FLAG_range, &ans);
   
   for (int i = 0; i < nGene; ++i) {
@@ -199,7 +200,8 @@ SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile, SEXP arg_g
   int numAllocated = 0;
   
   // allocate return value
-  numAllocated += createList(nGene, &ans);
+  PROTECT(ans = allocVector(VECSXP, nGene));
+  numAllocated++;
   numAllocated += setListNames(FLAG_geneName, &ans);
 
   OrderedMap< std::string, std::string> geneRange;
